@@ -16,8 +16,12 @@ case $PYTHON_VERSION in
   INSTALLER_NAME=python-$FULL_VERSION-macosx10.9.pkg
   ;;
 3.10)
-  FULL_VERSION=3.10.3
-  INSTALLER_NAME=python-$FULL_VERSION-macosx11.pkg
+  FULL_VERSION=3.10.4
+  INSTALLER_NAME=python-$FULL_VERSION-macos11.pkg
+  ;;
+3.11)
+  FULL_VERSION=3.11.0
+  INSTALLER_NAME=python-$FULL_VERSION-macos11.pkg
   ;;
 esac
 
