@@ -1,5 +1,4 @@
-#*****************************************************************************
-#   Copyright 2004-2008 Steve Menard
+# *****************************************************************************
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -13,14 +12,22 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 #
-#*****************************************************************************
-import sys
+#   See NOTICE file for details.
+#
+# *****************************************************************************
+import sys as _sys
 
 from . import _jproxy
 from . import _jclass
 
+__all__ = ['setupGuiEnvironment', 'shutdownGuiEnvironment']
+
+# FIXME this is not documented
+# FIXME this is darwin specific
+
+
 def setupGuiEnvironment(cb):
-    if sys.platform == 'darwin':
+    if _sys.platform == 'darwin':
         from PyObjCTools import AppHelper
         m = {'run': cb}
         proxy = _jproxy.JProxy('java.lang.Runnable', m)
@@ -30,7 +37,8 @@ def setupGuiEnvironment(cb):
     else:
         cb()
 
+
 def shutdownGuiEnvironment():
-    if sys.platform == 'darwin':
+    if _sys.platform == 'darwin':
         from PyObjCTools import AppHelper
         AppHelper.stopEventLoop()
