@@ -54,7 +54,7 @@ public:
 	virtual void getView(JPArrayView& view) override;
 	virtual void releaseView(JPArrayView& view) override;
 	virtual const char* getBufferFormat() override;
-	virtual ssize_t getItemSize() override;
+	virtual Py_ssize_t getItemSize() override;
 	virtual void copyElements(JPJavaFrame &frame,
 			jarray a, jsize start, jsize len,
 			void* memory, int offset) override;
@@ -62,4 +62,4 @@ public:
 			JPPyBuffer& view, int subs, int base, jobject dims) override;
 } ;
 
-#endif // _JP_VOID_TYPE_H_
\ No newline at end of file
+#endif // _JP_VOID_TYPE_H_
