@@ -274,7 +274,7 @@ void JPLongType::getView(JPArrayView& view)
 	JPJavaFrame frame = JPJavaFrame::outer(view.getContext());
 	view.m_Memory = (void*) frame.GetLongArrayElements(
 			(jlongArray) view.m_Array->getJava(), &view.m_IsCopy);
-	view.m_Buffer.format = "q";
+	view.m_Buffer.format = "=q";
 	view.m_Buffer.itemsize = sizeof (jlong);
 }
 
@@ -294,10 +294,10 @@ void JPLongType::releaseView(JPArrayView& view)
 
 const char* JPLongType::getBufferFormat()
 {
-	return "q";
+	return "=q";
 }
 
-ssize_t JPLongType::getItemSize()
+Py_ssize_t JPLongType::getItemSize()
 {
 	return sizeof (jlong);
 }
