@@ -43,8 +43,28 @@ PyObject* PyJPValue_alloc(PyTypeObject* type, Py_ssize_t nitems )
 	JP_PY_TRY("PyJPValue_alloc");
 	// Modification from Python to add size elements
 	const size_t size = _PyObject_VAR_SIZE(type, nitems + 1) + sizeof (JPValue);
-	PyObject *obj = (PyType_IS_GC(type)) ? _PyObject_GC_Malloc(size)
-			: (PyObject *) PyObject_MALLOC(size);
+	PyObject *obj = NULL;
+	if (PyType_IS_GC(type))
+	{
+		// Horrible kludge because python lacks an API for allocating a GC type with extra memory
+		// The private method _PyObject_GC_Alloc is no longer visible, so we are forced to allocate
+		// a different type with the extra memory and then hot swap the type to the real one.
+		PyTypeObject type2;
+		type2.tp_basicsize = size;
+		type2.tp_itemsize = 0;
+		type2.tp_name = NULL;
+		type2.tp_flags = type->tp_flags;
+		type2.tp_traverse = type->tp_traverse;
+
+		// Allocate the fake type
+		obj = PyObject_GC_New(PyObject, &type2);
+
+		// Note the object will be inited twice which should not leak. (fingers crossed)
+	}
+	else
+	{
+		obj = (PyObject*) PyObject_MALLOC(size);
+	}
 	if (obj == NULL)
 		return PyErr_NoMemory(); // GCOVR_EXCL_LINE
 	memset(obj, 0, size);
@@ -305,4 +325,4 @@ bool PyJPValue_isSetJavaSlot(PyObject* self)
 		return false;  // GCOVR_EXCL_LINE
 	JPValue* slot = (JPValue*) (((char*) self) + offset);
 	return slot->getClass() != NULL;
-}
\ No newline at end of file
+}
