@@ -26,4 +26,9 @@ class KeywordsTestCase(common.JPypeTestCase):
 
     def testKeywords(self):
         for kw in keyword.kwlist:
-            self.assertTrue(jpype._pykeywords.pysafe(kw).endswith("_"))
+            safe = jpype._pykeywords.pysafe(kw)
+            if kw.startswith("_"):
+                continue
+            self.assertEqual(type(safe), str, "Fail on keyword %s" % kw)
+            self.assertTrue(safe.endswith("_"))
+        self.assertEqual(jpype._pykeywords.pysafe("__del__"), None)
